function L = assemLoad_Neu_LFE(Mesh,GHandle,varargin)
% ASSEMNEU_LFE Neumann boundary conditions.
Mesh = add_Edge2Elem(Mesh);
Loc = get_BdEdges(Mesh);
Mesh.BdFlags = zeros(size(Mesh.Edges,1),1);
Mesh.BdFlags(Loc) = -1;
L = zeros(size(Mesh.Coordinates,1),1);
[QuadRule.x QuadRule.w] = gaussquad(2,0,1);
  % Initialize constants

  nGauss = size(QuadRule.w,1);
  
  % Precompute shape functions
  
  N = shap_LFE([QuadRule.x zeros(nGauss,1)]);

  % Extract Neumann edges
  
  Loc = get_BdEdges(Mesh);
    
    for j2 = Loc'
        
      % Compute element map
      
      if(Mesh.Edge2Elem(j2,1))
          
        % Match orientation to left hand side element
        
        Elem = Mesh.Edge2Elem(j2,1);
        EdgeLoc = Mesh.EdgeLoc(j2,1);
        id_s = Mesh.Elements(Elem,rem(EdgeLoc,3)+1);
        id_e = Mesh.Elements(Elem,rem(EdgeLoc+1,3)+1);
          
      else
        
        % Match orientation to right hand side element  
          
        Elem = Mesh.Edge2Elem(j2,2);
        EdgeLoc = Mesh.EdgeLoc(j2,2);
        id_s = Mesh.Elements(Elem,rem(EdgeLoc,3)+1);
        id_e = Mesh.Elements(Elem,rem(EdgeLoc+1,3)+1);
        
      end
      Q0 = Mesh.Coordinates(id_s,:);
      Q1 = Mesh.Coordinates(id_e,:);
      x = ones(nGauss,1)*Q0+QuadRule.x*(Q1-Q0);
      dS = norm(Q1-Q0);
      
      % Evaluate Neumannn boundary data
      
      FVal = GHandle(x,varargin{:});

      % Numerical integration along an edge
    
      Lloc(1) = sum(QuadRule.w.*FVal.*N(:,1))*dS;
      Lloc(2) = sum(QuadRule.w.*FVal.*N(:,2))*dS;
  
      % Add contributions of Neumann data to load vector
      
      L(id_s) = L(id_s)+Lloc(1);
      L(id_e) = L(id_e)+Lloc(2);
      
    end    

  
return
