#!/bin/bash
#	Roman Andreev
#	Seminar for Applied Mathematics
#	ETH Zurich, 2011

dir=$1 # working directory, eg temp/01_MM_324
arc=$2 # zip file to be processed, eg /tmp/solution.zip
pass=_$3 # $3 must be GAUSS
ID=$4 # appended to the resulting filenames (zip and pdf)

POST=$ID"_"$(date +%Y%m%d-%Hh%Mm-%N)

#echo $trailing
if [ ! "$pass" == "_GAUSS" ]; then exit 1; fi

pdf=submission_$POST.pdf

# Note: two files have a special meaning:
# 000-FILI-000.txt  and  000-IMHO-000.txt
# Do not change these filenames

cd $dir;

echo "";
echo "<br>";
echo "Host: $(hostname)"; echo "<br>";
echo "Archive source: ${arc}"; echo "<br>";
echo "BTW, LS: "$(ls )"<br>";

echo "";
echo "Try to unzip the submission archive"; echo "<br>";
unzip -oq $arc -d . 2>&1 && (

echo "";
echo "Expand the directory tree by replacing '/' by '_'"; echo "<br>";
IFS=$'\t\n\r';
for i in $(find -type f | sed 's#^./*##' | grep -v '\.svn'); do
	mv -vf "$i" $(echo $i | sed 's#/#_#g' | sed 's# #_#g' | sed 's#&#_#g');
	echo "<br>";
done;
echo "";
echo "BTW, LS: "$(ls )"<br>";
# Delete all subdirectories
for i in $(find . -type d | grep -v "^.$"); do rm -rf "$i"; done
# Only keep the first 30 files
for i in $(find . -type f | tail -n +50); do rm -f "$i"; done
IFS=$' \t\n\r';

echo "";
echo "BTW, LS: "$(ls )"<br>";

echo "";
echo "Append lowercase extensions to uppercase extensions"; echo "<br>";
for f in $(ls *.* | sed -n '/.*\.[A-Z]\+$/p'); do mv -vf $(echo $f | sed 's/\(.*\)\.\([A-Z]\+\)/& \1_\2.\L\2/'); done;
echo "BTW, LS: "$(ls )"<br>";

echo "";
echo "Remove unusable files, create a list of files"; echo "<br>";
#
for i in $(find . -size -2c); do mv -vf $i $i-skip; done;
for i in $(ls *_MACOSX_*); do mv -vf $i $i-skip; done;
for i in $(ls *~); do mv -vf $i $i-skip; done;
for i in $(ls *.dat *.p *.asv *.doc *.docx *.fig *.xps *.odt); do mv -vf $i $i-skip; done;
#
ls | grep -v "^000-[A-Z]*-000.txt$" > 000-FILI-000.txt;
rm -f ./*-skip;

echo "";
echo "Comment on silly file formats"; echo "<br>";
sed -i 's/\.doc[x]*-skip$/\.doc(x) (not OK, convert to PDF!)/g' 000-FILI-000.txt;
sed -i 's/\.odt*-skip$/\.odt (not OK, convert to PDF!)/g' 000-FILI-000.txt;
sed -i 's/\.fig-skip$/\.fig (not OK, save as image or PDF!)/g' 000-FILI-000.txt;
sed -i 's/\.bmp$/& (OK, but use PNG or PDF next time!)/g' 000-FILI-000.txt;
sed -i 's/\.rtf$/& (Maybe OK, but use TXT or PDF instead!)/g' 000-FILI-000.txt;
sed -i 's/-skip$/ (file skipped!)/g' 000-FILI-000.txt;

echo "";
echo "Get a local copy of the archive"; echo "<br>";
cp $arc ./submission_$POST.zip 2>&1;

echo "";
echo "Add the comment file to local copy"; echo "<br>";
zip -u ./submission_$POST.zip 000-IMHO-000.txt 2>&1;

echo "";
echo "For the purpose of the PDF, move the list of files to the comment file"; echo "<br>";
echo "" >> 000-IMHO-000.txt;
echo "" >> 000-IMHO-000.txt;
echo "File list: " >> 000-IMHO-000.txt;
cat 000-FILI-000.txt >> 000-IMHO-000.txt;
rm 000-FILI-000.txt 2>&1;

echo "";
echo "Run some file type diagnostics"; echo "<br>";
echo "" >> 000-IMHO-000.txt;
for i in $(ls *.ps *.eps); do ( file -ib $i | grep -q "/postscript" ) || (echo "Conflict in $(file $i). File ignored!" >> 000-IMHO-000.txt; rm -vf $i;); done;
for i in $(ls *.pdf); do ( file -ib $i | grep -q "/pdf" ) || (echo "Conflict in $(file $i). File ignored!" >> 000-IMHO-000.txt; rm -vf $i;); done;
for i in $(ls *.txt *.m *.py); do ( file -ib $i | grep -q "/rtf" ) && (echo "$(file $i) -> interpreting as RTF!" >> 000-IMHO-000.txt; mv -vf $i $i.rtf;); done;
for i in $(ls *.txt *.m *.py); do ( file -ib $i | grep -q "text/" ) || (echo "Conflict in $(file $i), text/* expected. File ignored!" >> 000-IMHO-000.txt; rm -vf $i;); done;

echo "" >> 000-IMHO-000.txt;
echo "Files not appearing below on a separate page could not be interpreted." >> 000-IMHO-000.txt;
echo "" >> 000-IMHO-000.txt;
echo "Feedback:" >> 000-IMHO-000.txt;

echo "";
echo "BTW, LS: "$(ls )"<br>";

) && (
paps="paps";

echo "";
echo "Try to convert RTF files to plain text"; echo "<br>";
echo "BTW, LS: "$(ls )"<br>";
for f in $(ls *.rtf); do
	# Strip all format comments
	echo "To text: ${f}";
	sed 's/\\[a-z0-9]*//g;s/{[^{]*}//g;/^$/d' "${f}" > "${f}".txt;
	rm -f "${f}";
done;

echo "";
echo "Try to convert all unknown files to postscript"; echo "<br>";
echo "BTW, LS: "$(ls )"<br>";
for f in $(ls | grep -v "\.zip$" | grep -v "\.pdf$" | grep -v "\.ps$" | grep -v "\.eps$" | grep -v "\.txt$" | grep -v "\.m$" | grep -v "\.py$"); do
	echo $f"<br>";
	# Note: eps better than pdf here due to "gs ..." (may create funny pages otherwise)
	# If 'convert' does not recognize the format, try to interpret as plain text
	convert $f $f.eps || ( (file -ib $f | grep -q "text/plain") && (mv $f $f.txt) );

	# Remove the file: if conversion took place, a copy is already available
	rm -f $f;
done;

echo "";
echo "Convert plain text files to postscript"; echo "<br>";
echo "BTW, LS: "$(ls )"<br>";
for f in $(ls *.txt *.m *.py); do
	echo "To postscript: ${f} <br>";
	# Try to convert from Windows/Mac to Unix format
	dos2unix $f;
	# If the encoding is not UTF, convert to UTF
	(file -b $f | grep -q "UTF") || (iconv -f ISO88592 -t UTF8 $f > $f.temp; mv $f.temp $f);
    # Add header
    echo "+-------------------------------------------------------------" > header;
    echo "| File: ${f}" >> header;
    date +"| Time: %A %Y-%m-%d %T %Z (UTC %z)" >> header;
    echo "+-------------------------------------------------------------" >> header;
    echo "" >> header;
    cat header $f >> temp;
    rm -f header;
	# Process the UTF8 file to postscript
	$paps temp > $f.ps;
	# Remove the original
	rm -f $f temp;
done;

exit 0;
) && (

echo "";
echo "Writing file: "$pdf.temp"<br>";
echo "From sources: " $(ls *.ps *.eps *.pdf | sort) "<br>";

## Version via postscript
#gs -dNOPAUSE -sDEVICE=pswrite -sPAPERSIZE=a4 -sOUTPUTFILE=$pdf.temp -dEPSFitPage -dPDFFitPage -dBATCH $(ls *.ps *.eps *.pdf | sort);
#echo "<br>";
#rm -rf *.ps *.eps *.pdf;
#psnup -2 -s0.6 -m1cm -pa4 -d $pdf.temp | ps2pdf14 - $pdf 2>&1;
#rm *.temp;

## Version via pdf
gs -dNOPAUSE -sDEVICE=pdfwrite -sPAPERSIZE=a4 -sOUTPUTFILE=$pdf.temp -dEPSFitPage -dPDFFitPage -dBATCH $(ls *.ps *.eps *.pdf | sort);
echo "<br>";
rm -rf *.ps *.eps *.pdf;
#pdfjam --nup 2x2 $pdf.temp -o $pdf || mv $pdf.temp $pdf;
mv $pdf.temp $pdf;
rm -rf *.temp;

) || echo "Could not unpack the zip file.""<br>";

